# traint.ai

## Machine Learning for everyone!

🚀 Traint.ai is a service that does all the heavy lifting for you so you can focus on enjoying the benefits of machine learning.

## Early access

Right now, we are in a pre-alpha phase.
If you are interested in traint.ai, feel free to message us: traint@heureka-labs.de
